@@ -235,7 +235,7 @@ abesspca <- function(x,
     exchange_num = c_max,
     path_type = path_type,
     is_warm_start = warm.start,
-    ic_type = 1,
+    ic_type = ic_type,
     ic_coef = ic_scale,
     Kfold = nfolds,
     sequence = s_list_bool,
